%Example Code for level model in Hausman and Kuersteiner (2008)

numboot=200; %set number of bootstrap replications

load('Example_8_10_402.mat');
X=xlev;
Y=ylev;
n=50;
T=10;
%construct matrix with fixed effects
Z=kron(eye(T),ones(n,1));
V=[];
Type='FD';
ta=1.96; %ciritcal value for the standard normal

%Compute corrected critical values (Rothenberg, 1988, p.1007)

A1t=(1+ta^2)/2+2*(T-2);             
t1=ta*(1+A1t/(2*n));            
 
ConsT=logical(ones(T,1)*ones(1,T)); %place no restrictions on temporal dependence
ConsN=logical(zeros(n,n)); %force independence over cross-section

[GammaHatGLS,GammaVarGLS]=GLS(Y,X,Z,V,Type,ConsT,ConsN);

if abs(GammaHatGLS/sqrt(GammaVarGLS))>t1
   rejectPar=1;
end

%bootstrap

beta=regress(Y,[X Z]);
betaR=regress(Y,Z);
resid=Y-[X Z]*beta;

e=reshape(resid,n,T)';
Yboot=[];
for i=1:numboot;
    ind=ceil(rand(1,n)*n);  %select histories of states randomly
    ei=reshape(e(:,ind)',n*T,1);
    Ystar=Z*betaR+ei; %enforce null-hypothesis for the bootstrapped sample
    Yboot=[Yboot Ystar];
end

tboot=BootFGLS(Yboot,X,Z,V,ta,numboot,Type,ConsT,ConsN);
